@@ -35,7 +35,35 @@ sampleCohorts <- function(cohort,
   if (length(cohortId) == 0) {
     cli::cli_inform("Returning entry cohort as `cohortId` is not valid.")
     # return entry cohort as cohortId is used to modify not subset
-    cdm[[name]] <- cohort |> dplyr::compute(name = name, temporary = FALSE)
+    cdm[[name]] <- cohort |> dplyr::compute(name = name, temporary = FALSE,
+                                            logPrefix = "CohortConstructor_sampleCohorts_entry_")
+    useIndexes <- getOption("CohortConstructor.use_indexes")
+    if (!isFALSE(useIndexes)) {
+      addIndex(
+        cohort = cdm[[name]],
+        cols = c("subject_id", "cohort_start_date")
+      )
+    }
+    return(cdm[[name]])
+  }
+
+  if (all(cohort |>
+          dplyr::filter(.data$cohort_definition_id %in% .env$cohortId) |>
+          dplyr::distinct(.data$cohort_definition_id, .data$subject_id) |>
+          dplyr::group_by(.data$cohort_definition_id) |>
+          dplyr::tally() |>
+          dplyr::pull() <= n)) {
+    cli::cli_inform("Returning entry cohort as the size of the cohorts to be sampled is equal or smaller than `n`.")
+    # return entry cohort as cohortId is used to modify not subset
+    cdm[[name]] <- cohort |> dplyr::compute(name = name, temporary = FALSE,
+                                            logPrefix = "CohortConstructor_sampleCohorts_return_")
+    useIndexes <- getOption("CohortConstructor.use_indexes")
+    if (!isFALSE(useIndexes)) {
+      addIndex(
+        cohort = cdm[[name]],
+        cols = c("subject_id", "cohort_start_date")
+      )
+    }
     return(cdm[[name]])
   }
 
@@ -53,7 +81,8 @@ sampleCohorts <- function(cohort,
     dplyr::ungroup() |>
     dplyr::relocate(dplyr::all_of(omopgenerics::cohortColumns("cohort")))  |>
     dplyr::compute(name = name,
-                   temporary = FALSE)
+                   temporary = FALSE,
+                   logPrefix = "CohortConstructor_sampleCohorts_sample_")
 
   cdm[[name]] <- cdm[[name]] |>
     omopgenerics::recordCohortAttrition(
@@ -61,13 +90,5 @@ sampleCohorts <- function(cohort,
       cohortId = cohortId
     )
 
-  useIndexes <- getOption("CohortConstructor.use_indexes")
-  if (!isFALSE(useIndexes)) {
-    addIndex(
-      cohort = cdm[[name]],
-      cols = c("subject_id", "cohort_start_date")
-    )
-  }
-
   return(cdm[[name]])
 }
