@@ -55,11 +55,17 @@ stratifyCohorts <- function(cohort,
 
   if (length(strata) == 0 ||
     sum(cohortCount(cohort)$number_records) == 0) {
-    return(subsetCohorts(
-      cohort = cohort,
-      cohortId = cohortId,
-      name = name
-    ))
+    if (removeStrata) {
+      cohort <- cohort |>
+        dplyr::select(!dplyr::any_of(unique(unlist(strata))))
+    }
+    return(
+      subsetCohorts(
+        cohort = cohort,
+        cohortId = cohortId,
+        name = name
+      )
+    )
   }
 
   strataCols <- unique(unlist(strata))
@@ -150,7 +156,8 @@ stratifyCohorts <- function(cohort,
   newCohort <- purrr::reduce(newCohort, dplyr::union_all) |>
     dplyr::select(!dplyr::all_of(c("target_cohort_id", strataCols[removeStrata]))) |>
     dplyr::relocate(dplyr::all_of(omopgenerics::cohortColumns("cohort"))) |>
-    dplyr::compute(name = name, temporary = FALSE) |>
+    dplyr::compute(name = name, temporary = FALSE,
+                   logPrefix = "CohortConstructor_stratifyCohorts_reduce_") |>
     omopgenerics::newCohortTable(
       cohortSetRef = newSettings,
       cohortAttritionRef = newAttrition,
