@@ -16,10 +16,10 @@ test_that("simple duckdb checks", {
         "observation_period_id" = as.integer(1:4),
         "person_id" = as.integer(c(1, 2, 2, 3)),
         "observation_period_start_date" = as.Date(c(
-          "1993-04-19", "2010-03-12", "2031-08-23", "2020-10-06"
+          "1993-04-19", "2010-03-12", "2017-08-23", "2020-10-06"
         )),
         "observation_period_end_date" = as.Date(c(
-          "2033-10-11", "2017-01-01", "2045-03-12", "2100-12-31"
+          "2023-10-11", "2017-01-01", "2023-03-12", "2024-01-01"
         )),
         "period_type_concept_id" = 0L
       )
@@ -30,10 +30,10 @@ test_that("simple duckdb checks", {
         "cohort_definition_id" = as.integer(c(1, 1, 1, 2)),
         "subject_id" = as.integer(c(1, 2, 3, 1)),
         "cohort_start_date" = as.Date(c(
-          "2032-01-19", "2039-11-12", "2036-03-16", "2003-12-15"
+          "2012-01-19", "2010-11-12", "2021-03-16", "2003-12-15"
         )),
         "cohort_end_date" = as.Date(c(
-          "2033-10-11", "2045-01-12", "2074-05-18", "2010-05-25"
+          "2023-10-11", "2015-01-12", "2024-01-01", "2010-05-25"
         ))
       )
     )
@@ -68,18 +68,14 @@ test_that("simple duckdb checks", {
   expect_identical(
     x,
     dplyr::tibble(
-      "subject_id" = as.integer(c(1, 2, 3)),
-      "cohort_start_date" = as.Date(c(
-        "2033-04-19", "2040-01-15", "2045-08-20"
-      )),
-      "cohort_end_date" = as.Date(c(
-        "2033-10-11", "2045-01-12", "2065-08-19"
-      ))
+      "subject_id" = as.integer(c()),
+      "cohort_start_date" = as.Date(c()),
+      "cohort_end_date" = as.Date(c())
     )
   )
   id <- settings(cdm$cohort2) |>
     dplyr::filter(
-      sex == "Both" & age_range == "40_59" &
+      sex == "Both" & age_range == "0_19" &
         min_prior_observation == 0 &
         min_future_observation == 365 &
         grepl("cohort_1", cohort_name)
@@ -89,9 +85,9 @@ test_that("simple duckdb checks", {
   expect_identical(
     x,
     dplyr::tibble(
-      "subject_id" = c(2L, 3L),
-      "cohort_start_date" = as.Date(c("2040-01-15", "2045-08-20")),
-      "cohort_end_date" = as.Date(c("2045-01-12", "2065-08-19"))
+      "subject_id" = c(1L, 2L, 3L),
+      "cohort_start_date" = as.Date(c("2012-01-19", "2010-11-12", "2021-03-16")),
+      "cohort_end_date" = as.Date(c("2013-04-18", "2015-01-12", "2024-01-01"))
     )
   )
 
@@ -156,9 +152,9 @@ test_that("simple duckdb checks", {
   expect_identical(
     x,
     dplyr::tibble(
-      "subject_id" = as.integer(c(1, 2, 3)),
-      "cohort_start_date" = as.Date(c("1993-04-19", "2010-03-12", "2020-10-06")),
-      "cohort_end_date" = as.Date(c("2013-04-18", "2017-01-01", "2025-08-19"))
+      "subject_id" = as.integer(c(1, 2, 2, 3)),
+      "cohort_start_date" = as.Date(c("1993-04-19", "2010-03-12", "2017-08-23", "2020-10-06")),
+      "cohort_end_date" = as.Date(c("2013-04-18", "2017-01-01", "2020-01-14", "2024-01-01"))
     )
   )
   id <- settings(cdm$obs1) |>
@@ -172,9 +168,9 @@ test_that("simple duckdb checks", {
   expect_identical(
     x,
     dplyr::tibble(
-      "subject_id" = c(1L, 2L, 3L),
-      "cohort_start_date" = as.Date(c("1994-04-19", "2011-03-12", "2021-10-06")),
-      "cohort_end_date" = as.Date(c("2013-04-18", "2017-01-01", "2025-08-19"))
+      "subject_id" = c(1L, 2L, 2L, 3L),
+      "cohort_start_date" = as.Date(c("1994-04-19", "2011-03-12", "2018-08-23", "2021-10-06")),
+      "cohort_end_date" = as.Date(c("2013-04-18", "2017-01-01", "2020-01-14", "2024-01-01"))
     )
   )
 
@@ -291,9 +287,9 @@ test_that("simple duckdb checks", {
   expect_identical(
     x,
     dplyr::tibble(
-      "subject_id" = c(1L, 2L, 3L),
-      "cohort_start_date" = as.Date(c("1993-04-19", "2010-03-12", "2020-10-06")),
-      "cohort_end_date" = as.Date(c("2013-04-18", "2017-01-01", "2025-08-19"))
+      "subject_id" = c(1L, 2L, 2L, 3L),
+      "cohort_start_date" = as.Date(c("1993-04-19", "2010-03-12", "2017-08-23", "2020-10-06")),
+      "cohort_end_date" = as.Date(c("2013-04-18", "2017-01-01", "2020-01-14", "2024-01-01"))
     )
   )
   id <- settings(cdm$obs_new) |>
@@ -351,15 +347,15 @@ test_that("cohort Id, name, additional columns", {
   x1 <- collectCohort(cdm$cohort3, 1)
   x3 <- collectCohort(cdm$cohort3, 3)
   expect_identical(x1, dplyr::tibble(
-      subject_id = c(1, 1, 2, 3) |> as.integer(),
-      cohort_start_date = as.Date(c("2001-04-03", "2002-05-07", "1999-07-26", "2015-02-19")),
-      cohort_end_date = as.Date(c("2002-05-06", "2005-11-07", "2002-09-17", "2015-06-27"))
-    ))
+    subject_id = c(1, 1, 2, 3) |> as.integer(),
+    cohort_start_date = as.Date(c("2001-04-03", "2002-05-07", "1999-07-26", "2015-02-19")),
+    cohort_end_date = as.Date(c("2002-05-06", "2005-11-07", "2002-09-17", "2015-06-27"))
+  ))
   expect_identical(x3, dplyr::tibble(
-      subject_id = c(1, 1, 2) |> as.integer(),
-      cohort_start_date = as.Date(c("2001-07-08", "2002-05-07", "2000-05-09")),
-      cohort_end_date = as.Date(c("2002-05-06", "2005-11-07", "2002-09-17"))
-    ))
+    subject_id = c(1, 1, 2) |> as.integer(),
+    cohort_start_date = as.Date(c("2001-07-08", "2002-05-07", "2000-05-09")),
+    cohort_end_date = as.Date(c("2002-05-06", "2005-11-07", "2002-09-17"))
+  ))
   expect_true(all(
     attrition(cdm$cohort3)$reason ==
       c('Initial qualifying events', 'Sex requirement: Male',
@@ -368,11 +364,11 @@ test_that("cohort Id, name, additional columns", {
         'Prior observation requirement: 400 days')
   ))
   expect_identical(settings(cdm$cohort3), dplyr::tibble(
-      cohort_definition_id = as.integer(1:3),
-      cohort_name = c("cohort_1_1", "cohort_2", "cohort_1_2"),
-      sex = c("Male", "Both", "Male"),
-      min_prior_observation = c(0, 0, 400)
-    ))
+    cohort_definition_id = as.integer(1:3),
+    cohort_name = c("cohort_1_1", "cohort_2", "cohort_1_2"),
+    sex = c("Male", "Both", "Male"),
+    min_prior_observation = c(0, 0, 400)
+  ))
 
   expect_no_error(
     cohort <- trimDemographics(cohort = cdm$cohort2,
@@ -396,20 +392,22 @@ test_that("test indexes - postgres", {
                        host = Sys.getenv("CDM5_POSTGRESQL_HOST"),
                        user = Sys.getenv("CDM5_POSTGRESQL_USER"),
                        password = Sys.getenv("CDM5_POSTGRESQL_PASSWORD"))
-  cdm <- CDMConnector::cdm_from_con(
+  cdm <- CDMConnector::cdmFromCon(
     con = db,
-    cdm_schema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA"),
-    write_schema = c(schema =  Sys.getenv("CDM5_POSTGRESQL_SCRATCH_SCHEMA"),
-                     prefix = "cc_"),
-    achilles_schema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA")
+    cdmSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA"),
+    writeSchema = Sys.getenv("CDM5_POSTGRESQL_SCRATCH_SCHEMA"),
+    writePrefix = "cc_",
+    achillesSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA")
   )
 
-  cdm <- omopgenerics::insertTable(cdm = cdm,
-                                   name = "my_cohort",
-                                   table = data.frame(cohort_definition_id = 1L,
-                                                      subject_id = 1L,
-                                                      cohort_start_date = as.Date("2009-01-01"),
-                                                      cohort_end_date = as.Date("2009-01-02")))
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm,
+    name = "my_cohort",
+    table = data.frame(cohort_definition_id = 1L,
+                       subject_id = 1L,
+                       cohort_start_date = as.Date("2009-01-01"),
+                       cohort_end_date = as.Date("2009-01-02"))
+  )
   cdm$my_cohort <- omopgenerics::newCohortTable(cdm$my_cohort)
   cdm$my_cohort <- trimDemographics(cdm$my_cohort, ageRange = list(c(0, 50)))
 
@@ -419,5 +417,5 @@ test_that("test indexes - postgres", {
   )
 
   omopgenerics::dropTable(cdm = cdm, name = dplyr::starts_with("my_cohort"))
-  CDMConnector::cdm_disconnect(cdm = cdm)
+  CDMConnector::cdmDisconnect(cdm = cdm)
 })
